@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.7 2006/12/23 11:11:30 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -94,7 +94,6 @@ class SyL_ConfigActions extends SyL_Config
     function setController(&$controller)
     {
         $this->dm =& $controller->container->getComponent('datamanager');
-        $this->cm =& $controller->container->getComponent('componentmethod');
     }
 
     /**
@@ -209,7 +208,7 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$component_name]['args'] = array();
 
                 // ץꥱ󥳥ݡͥ̾å
-                $this->cm->addAppComponent($component_name, '', $component_priority);
+                 $this->dm->cm->addAppComponent($component_name, '', $component_priority);
                 break;
 
             default:
@@ -266,7 +265,7 @@ class SyL_ConfigActions extends SyL_Config
 
                 case '/actions/action/components/component/final':
                     // ץꥱ󥳥ݡͥ̾å
-                    $this->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
+                     $this->dm->cm->addAppComponent($component_name, $attribute['name'], $component_priority);
                     break;
                 }
             }
