@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.3 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,7 +46,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.3 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
@@ -99,24 +99,6 @@ class SyL_ControllerCmd extends SyL_Controller
         $this->raiseEvent('executeStream', $config_file);
     }
 
-    /**
-     * ǽ
-     * register_shutdown_function
-     *
-     * @access protected
-     */
-    function finalStream()
-    {
-        // ٥ȼ¹
-        parent::finalStream();
-
-        // ݡͥȤȤϿ줿destory᥽åɼ¹
-        $cnt = count($this->destory_objects);
-        for ($i=0; $i<$cnt; $i++) {
-          call_user_func($this->destory_objects[$i]);
-        }
-    }
-
     /**
      * ȥݥ
      *
