@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.3 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.2 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.3 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerWeb extends SyL_Controller
@@ -79,13 +79,6 @@ class SyL_ControllerWeb extends SyL_Controller
      * @var bool
      */
     var $is_execute_action = true;
-    /**
-     * ǡ饹
-     * 
-     * @access private
-     * @var bool
-     */
-    var $dm = null;
 
     /**
      * 󥹥ȥ饯
@@ -157,24 +150,6 @@ class SyL_ControllerWeb extends SyL_Controller
         $this->raiseEvent('executeStream', $config_file);
     }
 
-    /**
-     * ǽ
-     * register_shutdown_function
-     *
-     * @access protected
-     */
-    function finalStream()
-    {
-        // ٥ȼ¹
-        parent::finalStream();
-
-        // ݡͥȤȤϿ줿destory᥽åɼ¹
-        $cnt = count($this->destory_objects);
-        for ($i=0; $i<$cnt; $i++) {
-          call_user_func($this->destory_objects[$i]);
-        }
-    }
-
     /**
      * ȥݥ
      *
