@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.3 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.3 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
@@ -61,45 +61,26 @@ class SyL_ErrorCmd extends SyL_Error
     /**
      * 顼ϥɥ顼μ
      * 
-     * Loding Frameworkǥեȥ顼̤ܤȤ
-     * Ѥ롣
-     *
      * @access protected
-     * @param int 顼No
-     * @param string 顼å
      */
-    function errorHandler($error_no, $error_message)
+    function errorHandler()
     {
-        // ߤΥ顼٥뤫饨顼ɽ뤫Ƚ
-        if ($error_no & error_reporting()) {
-            // Хåե󥰥ꥢ
-            while (@ob_end_clean());
+        // Хåե󥰥ꥢ
+        // ɬ
+        ob_clean();
 
-            // ʣ顼åб
-            if (count($this->error_message) > 0) {
-                if ($error_message != '') {
-                    $error_message .= $this->eof;
-                }
-                foreach ($this->error_message as $tmp) {
-                    $error_message .= $tmp . $this->eof;
-                }
-            }
-            // 顼פμ
-            $error_type  = $this->getErrorType($error_no);
-            // 顼ȥ졼μ
-            $error_trace = SYL_ERROR_TRACE ? $this->getTraceConsole() : '';
-            // 顼å
-            $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
-            // 顼ɽ
-            $this->displayErrorDefault($error_string, $error_trace);
-            // 
-            $this->logging($error_no, $error_message);
-
-            exit;
-        } else {
-            // 
-            $this->logging($error_no, $error_message);
-        }
+        // 顼å
+        $error_message = implode($this->eof, $this->getErrorMessages()) . $this->eof;
+        // 顼פμ
+        $error_type  = $this->getErrorType();
+        // 顼ȥ졼μ
+        $error_trace = SYL_ERROR_TRACE ? $this->getTraceConsole() : '';
+        // 顼å
+        $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
+        // 顼åɽ
+        $this->displayErrorDefault($error_string, $error_trace);
+        // 
+        $this->logging();
     }
 
     /**
