@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -61,55 +61,42 @@ class SyL_ErrorWeb extends SyL_Error
     /**
      * 顼ϥɥ顼μ
      * 
-     * Loding Frameworkǥեȥ顼̤ܤȤ
-     * Ѥ롣
-     *
-     * @access protected
-     * @param int 顼No
-     * @param string 顼å
+     * @access public
+     * @param object ǡ֥
      */
-    function errorHandler($error_no, $error_message)
+    function errorHandler(&$dm)
     {
-        // ߤΥ顼٥뤫饨顼̤ɽ뤫Ƚ
-        if ($error_no & error_reporting()) {
-            // Хåե󥰥ꥢ
-            while (@ob_end_clean());
+        // Хåե󥰥ꥢ
+        // ɬ
+        ob_clean();
 
-            // ʣ顼åб
-            if (count($this->error_message) > 0) {
-                if ($error_message != '') {
-                    $error_message .= "<br>";
-                }
-                foreach ($this->error_message as $tmp) {
-                    $error_message .= $tmp . "<br>";
-                }
-            }
-            // 顼פμ
-            $error_type  = $this->getErrorType($error_no);
-            // 顼ȥ졼μ
-            $error_trace = SYL_ERROR_TRACE ? $this->getTraceHtml() : '';
+        // 顼å
+        $error_message = implode('<br>', $this->getErrorMessages());
+        // 顼פμ
+        $error_type  = $this->getErrorType();
+        // 顼ȥ졼μ
+        $error_trace = SYL_ERROR_TRACE ? $this->getTraceHtml() : '';
 
-            // 顼ɽȽ
-            $error_View_type = '';
-            switch (strtolower(SYL_ERROR_FORWARD_TYPE)) {
-            case 'template': $error_View_type = 'Template'; break;
-            case 'redirect': $error_View_type = 'Redirect'; break;
-            default:         $error_View_type = 'Default';  break;
-            }
-
-            // 顼ɽ
-            $func_name = "displayError{$error_View_type}";
-            // 顼å
-            $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
-            call_user_func(array(&$this, $func_name), $error_string, $error_trace);
-            // 
-            $this->logging($error_no, $error_message);
-
-            exit;
-        } else {
-            // 
-            $this->logging($error_no, $error_message);
+        // 顼ɽȽ
+        $error_View_type = explode('-', SYL_ERROR_FORWARD_TYPE);
+        switch (strtolower($error_View_type[0])) {
+        case 'template': $error_View_type[0] = 'Template'; break;
+        case 'redirect': $error_View_type[0] = 'Redirect'; break;
+        default:         $error_View_type[0] = 'Default';  break;
         }
+
+        if (!isset($error_View_type[1])) {
+            $error_View_type[1] = '';
+        }
+
+        // 顼ɽ
+        $func_name = "displayError{$error_View_type[0]}";
+        // 顼å
+        $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
+        // 顼åɽ
+        $this->{$func_name}($error_string, $error_trace, $error_View_type[1]);
+        // 
+        $this->logging();
     }
 
     /**
@@ -118,8 +105,9 @@ class SyL_ErrorWeb extends SyL_Error
      * @access private
      * @param string 顼å
      * @param string 顼ȥ졼
+     * @param string ӥ塼
      */
-    function displayErrorDefault($error_string, $error_trace)
+    function displayErrorDefault($error_string, $error_trace, $view_type)
     {
         echo $error_string;
         if ($error_trace) {
@@ -134,17 +122,27 @@ class SyL_ErrorWeb extends SyL_Error
      * @access private
      * @param string 顼å
      * @param string 顼ȥ졼
+     * @param string ӥ塼
      */
-    function displayErrorTemplate($error_string, $error_trace)
+    function displayErrorTemplate($error_string, $error_trace, $view_type)
     {
-        if (is_file(SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
-            // 顼ƥץ졼ɤ߹
-            // $error_string
-            // $error_trace
-            include_once SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE;
-        } else {
-            trigger_error("[SyL error] error template not found (" . SYL_WEBAPP_LIB_DIR . '/' . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR);
-        }
+        // ǡ饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
+        $dm =& new SyL_DataManager($this->controller);
+        $dm->setTemplateType($view_type);
+        $dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
+
+        // ӥ塼饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
+        $view =& SyL_View::getObject($dm);
+        $view->setParameter('error_message', $error_string);
+        $view->setParameter('error_trace',   $error_trace);
+        $view->render();
+
+        // ̱饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Response.php';
+        $res =& SyL_Response::getInstance();
+        $res->display($view);
     }
 
     /**
@@ -153,9 +151,12 @@ class SyL_ErrorWeb extends SyL_Error
      * @access private
      * @param string 顼å
      * @param string 顼ȥ졼
+     * @param string ӥ塼
      */
-    function displayErrorRedirect($error_message, $error_trace)
+    function displayErrorRedirect($error_string, $error_trace, $view_type)
     {
+        // ̱饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Response.php';
         SyL_Response::redirect(SYL_ERROR_FORWARD_FILE);
     }
 
@@ -172,16 +173,16 @@ class SyL_ErrorWeb extends SyL_Error
         $error_trace_result = '';
         if ($i > 0) {
             // 顼ȥ졼ɽκ
-            $error_trace_result .= '<table border="1" cellspacing="0" cellpadding="3" bgcolor="#FFFFFF">' . "\r\n";
-            $error_trace_result .= '<tr>' . "\r\n";
-            $error_trace_result .= '<td colspan="4">Debug Trace</td>' . "\r\n";
-            $error_trace_result .= '</tr>' . "\r\n";
-            $error_trace_result .= '<tr>'  . "\r\n";
+            $error_trace_result .= '<table border="1" cellspacing="0" cellpadding="3" bgcolor="#FFFFFF">' . $this->eof;
+            $error_trace_result .= '<tr>' . $this->eof;
+            $error_trace_result .= '<td colspan="4">Debug Trace</td>' . $this->eof;
+            $error_trace_result .= '</tr>' . $this->eof;
+            $error_trace_result .= '<tr>'  . $this->eof;
             $error_trace_result .= '<td bgcolor="#CCCCCC">#</td>';
             $error_trace_result .= '<td bgcolor="#CCCCCC">file</td>';
             $error_trace_result .= '<td bgcolor="#CCCCCC">line</td>';
-            $error_trace_result .= '<td bgcolor="#CCCCCC">function or method</td>' . "\r\n";
-            $error_trace_result .= '</tr>' . "\r\n";
+            $error_trace_result .= '<td bgcolor="#CCCCCC">function or method</td>' . $this->eof;
+            $error_trace_result .= '</tr>' . $this->eof;
             foreach ($error_trace as $value) {
                 if (($value['function'] == '') || ($value['function'] == 'unknown')) {
                     $value['function'] = '&nbsp;';
@@ -192,17 +193,18 @@ class SyL_ErrorWeb extends SyL_Error
                 if ($value['line'] == '') {
                     $value['line'] = '-';
                 }
-                $error_trace_result .= '<tr>' . "\r\n";
+                $error_trace_result .= '<tr>' . $this->eof;
                 $error_trace_result .= '<td>' . $i-- . '</td>';
                 $error_trace_result .= '<td>' . $value['file'] . '</td>';
                 $error_trace_result .= '<td align="right">' . $value['line'] . '</td>';
-                $error_trace_result .= '<td>' . $value['function'] . '</td>' . "\r\n";
-                $error_trace_result .= '</tr>' . "\r\n";
+                $error_trace_result .= '<td>' . $value['function'] . '</td>' . $this->eof;
+                $error_trace_result .= '</tr>' . $this->eof;
             }
-            $error_trace_result .= '</table>' . "\r\n";
+            $error_trace_result .= '</table>' . $this->eof;
         }
 
         return $error_trace_result;
     }
 }
+
 ?>
