@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.3 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.3 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.4 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ComponentMethod
@@ -86,7 +86,7 @@ class SyL_ComponentMethod
     function triggerFilter($name)
     {
         $name = "__filter_{$name}";
-        $component =& $this->_getComponent($name);
+        $component =& $this->getComponent($name);
         $args = func_get_args();
         array_shift($args);
         return call_user_func_array(array(&$component, $this->direct_method), $args);
@@ -101,7 +101,7 @@ class SyL_ComponentMethod
      */
     function triggerApp($name)
     {
-        $component =& $this->_getComponent($name);
+        $component =& $this->getComponent($name);
         $args = func_get_args();
         array_shift($args);
         return call_user_func_array(array(&$component, $this->direct_method), $args);
@@ -114,7 +114,7 @@ class SyL_ComponentMethod
      * @param string ݡͥ̾
      * @return object ݡͥ
      */
-    function &_getComponent($name)
+    function &getComponent($name)
     {
         if (!$this->controller->container->isComponent($name)) {
             trigger_error("[SyL error] Filter or AppComponent is not undefined (name: {$name})", E_USER_ERROR);
