@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.9 2006/12/25 17:40:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -74,7 +74,7 @@ define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.9 2006/12/25 17:40:42 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -107,6 +107,29 @@ class SyL_Controller
      * @var string
      */
     var $components_file_name = 'components.xml';
+    /**
+     * 顼ϥɥ᥽å̾
+     * ''ξϥ顼ϥɥꤷʤ
+     *
+     * @access private
+     * @var string
+     */
+    var $error_handler_method = 'errorStream';
+    /**
+     * ˴᥽å̾
+     * ''ξϽ˴᥽åɤꤷʤ
+     *
+     * @access private
+     * @var string
+     */
+    var $destory_handler_method = 'finalStream';
+    /**
+     * 顼
+     *
+     * @access private
+     * @var array
+     */
+    var $error = array();
     /**
      * ƥʥ֥
      *
@@ -114,21 +137,6 @@ class SyL_Controller
      * @var object
      */
     var $container = null;
-    /**
-     * ˴᥽å̾
-     * ''ξϽ˴᥽åɤưʤ
-     *
-     * @access private
-     * @var string
-     */
-    var $destory_method = 'finalStream';
-    /**
-     * ˴֥
-     *
-     * @access private
-     * @var array
-     */
-    var $destory_objects = array();
 
     /**
      * ȥ
@@ -138,7 +146,7 @@ class SyL_Controller
      * @access public
      * @param array Ķ
      */
-    function &getController($config)
+    function &getController($config=array())
     {
         static $singleton;
         if (!is_object($singleton)) {
@@ -184,11 +192,6 @@ class SyL_Controller
         // ɤ߹
         SyL_DefinesReader::readConfig($this->defines_file_name);
 
-        // shutdownϥɥ
-        if ($this->destory_method != '') {
-            register_shutdown_function(array(&$this, $this->destory_method));
-        }
-
         // ǥ쥯ȥ
         $this->action_dir = SYL_APP_DIR . '/actions';
         // ƥץ졼ȥǥ쥯ȥ
@@ -197,6 +200,15 @@ class SyL_Controller
         // ƥ
         $this->container =& new SyL_Container();
         $this->container->setComponent(SYL_CONFIG_CONTROLLER_NAME, $this);
+
+        // shutdownϥɥ
+        if ($this->destory_handler_method != '') {
+            register_shutdown_function(array(&$this, $this->destory_handler_method));
+        }
+        // 顼ϥɥ
+        if ($this->error_handler_method != '') {
+            set_error_handler(array(&$this, $this->error_handler_method));
+        }
     }
 
     /**
@@ -274,8 +286,41 @@ class SyL_Controller
     function finalStream()
     {
         // ٥ȼ¹
-        if (is_object($this->container)) {
-            $this->raiseEvent('finalStream');
+        $this->raiseEvent('finalStream');
+    }
+
+    /**
+     * 顼ϥɥ¹Խ
+     *
+     * @access protected
+     */
+    function errorStream()
+    {
+        static $num = 1;
+
+        // ߤΥ顼٥뤫饨顼̤ɽ뤫Ƚ
+        if (func_get_arg(0) & error_reporting()) {
+            if ($num++ > 1) {
+                echo "[SyL error] Error handler trigger 2";
+                exit;
+            }
+
+            // ƥʤ˥顼ȯȲɽʤʤ뤿
+            // 顼ɽϡob_clean() ǥꥢ롣
+            echo "[SyL_error] Controller init error message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3) . "\r\n";
+
+            for ($i=0; $i<5; $i++) {
+                $this->error[$i] = func_get_arg($i);
+            }
+            $this->error[5] = debug_backtrace();
+            // errorStream()᥽åɤϺ
+            array_shift($this->error[5]);
+
+            // ٥ȼ¹
+            $this->raiseEvent('errorStream');
+            exit;
+        } else {
+            // 󥰤Ȥ
         }
     }
 
@@ -310,6 +355,72 @@ class SyL_Controller
     {
         return $this->action_dir;
     }
+
+    /**
+     * 顼No
+     * 
+     * @access public
+     * @return string 顼No
+     */
+    function getErrorNo()
+    {
+        return isset($this->error[0]) ? $this->error[0] : '';
+    }
+
+    /**
+     * 顼å
+     * 
+     * @access public
+     * @return string 顼å
+     */
+    function getErrorMessage()
+    {
+        return isset($this->error[1]) ? $this->error[1] : '';
+    }
+
+    /**
+     * 顼ե
+     * 
+     * @access public
+     * @return string 顼ե
+     */
+    function getErrorFile()
+    {
+        return isset($this->error[2]) ? $this->error[2] : '';
+    }
+
+    /**
+     * 顼Կ
+     * 
+     * @access public
+     * @return string 顼Կ
+     */
+    function getErrorLine()
+    {
+        return isset($this->error[3]) ? $this->error[3] : '';
+    }
+
+    /**
+     * 顼ȯǤΤ٤ƤѿƤ
+     * 
+     * @access public
+     * @return array 顼ƥ
+     */
+    function getErrorContext()
+    {
+        return isset($this->error[4]) ? $this->error[4] : array();
+    }
+
+    /**
+     * 顼ȯǥХåȥ졼
+     * 
+     * @access public
+     * @return array ǥХåȥ졼
+     */
+    function getErrorTrace()
+    {
+        return isset($this->error[5]) ? $this->error[5] : array();
+    }
 }
 
 ?>
