@@ -27,11 +27,16 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.1 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * ݡͥȥ᥽åɥ饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_ComponentMethod.php';
+
 /**
  * ե졼ǡ饹
  *
@@ -39,7 +44,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.1 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataManager
@@ -51,13 +56,6 @@ class SyL_DataManager
      * @var string
      */
     var $template_type = '';
-    /**
-     * ƥץ졼ȥǥ쥯ȥ
-     * 
-     * @access private
-     * @var string
-     */
-    var $template_dir = '';
     /**
      * ƥץ졼ȥե
      * 
@@ -101,32 +99,34 @@ class SyL_DataManager
      */
     var $router = null;
     /**
-     * ꥯȥ֥
+     * ݡͥȥ᥽åɥ֥
      * 
      * @access private
      * @var object
      */
-    var $request = null;
+    var $cm = null;
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
      * @param object ȥ饪֥
+     */
+    function SyL_DataManager(&$controller)
+    {
+        $this->cm =& new SyL_ComponentMethod($controller);
+        $this->controller =& $controller;
+    }
+
+    /**
+     * ܾ󥪥֥Ȥ򥻥å
+     *
+     * @access public
      * @param object ܾ󥪥֥
      */
-    function SyL_DataManager(&$controller, &$router, &$request)
+    function setRouter(&$router)
     {
-        // ǥեȥƥץ졼ȥǥ쥯ȥ
-        $this->template_dir = $controller->getTemplateDir();
-
-        // ȥ򥻥å
-        $this->controller =& $controller;
-        // 롼֥ȥå
         $this->router =& $router;
-        // ꥯȥ֥ȥå
-        $this->request =& $request;
-
         // ǥХå - ξ
         SyL_Loggers::debug("[DataManager] action info - name: " . $this->getActionName() . " dir: " . $this->getActionDir() . " file: " . $this->getActionFile() . " class: " . $this->getClassName());
     }
@@ -139,7 +139,7 @@ class SyL_DataManager
      */
     function getActionName()
     {
-        return $this->router->getActionName();
+        return is_object($this->router) ? $this->router->getActionName() : null;
     }
 
     /**
@@ -161,7 +161,7 @@ class SyL_DataManager
      */
     function getActionFile()
     {
-        return $this->router->getActionFile();
+        return is_object($this->router) ? $this->router->getActionFile() : null;
     }
 
     /**
@@ -172,7 +172,7 @@ class SyL_DataManager
      */
     function getClassName()
     {
-        return $this->router->getClassName();
+        return is_object($this->router) ? $this->router->getClassName() : null;
     }
 
     /**
@@ -183,7 +183,7 @@ class SyL_DataManager
      */
     function getPathInfoArray()
     {
-        return $this->router->getPathInfoArray();
+        return is_object($this->router) ? $this->router->getPathInfoArray() : null;
     }
 
     /**
@@ -227,7 +227,7 @@ class SyL_DataManager
      */
     function getTemplateDir()
     {
-        return $this->convertPath($this->template_dir, true);
+        return $this->convertPath($this->controller->getTemplateDir(), true);
     }
 
     /**
@@ -305,18 +305,53 @@ class SyL_DataManager
         return $path;
     }
 
+    /**
+     * ե륿ͤ
+     * 
+     * @access public
+     * @param string ե륿̾
+     * @return mixed ե륿
+     */
+    function triggerFilter($name)
+    {
+        return $this->cm->triggerFilter($name);
+    }
+
+    /**
+     * ץꥱ󥳥ݡͥȤͤ
+     * 
+     * @access public
+     * @param string ץꥱ󥳥ݡͥ̾
+     * @return mixed ץꥱ󥳥ݡͥȤ
+     */
+    function triggerApp($name)
+    {
+        return $this->cm->triggerApp($name);
+    }
 
     /**
      * ¹Ƚ򥻥å
      * 
      * @access public
-     * @return bool true: ¹Ԥ롢false: ¹Ԥʤ
+     * @param bool true: ¹Ԥ롢false: ¹Ԥʤ
      */
     function setExecuteAction($is_execute_action)
     {
         $this->controller->setExecuteAction($is_execute_action);
     }
 
+    /**
+     * ݡͥȥ֥Ȥ򥻥å
+     * 
+     * @access public
+     * @param string ݡͥ̾
+     * @return object ݡͥ
+     */
+    function &getComponent($name)
+    {
+        return $this->controller->container->getComponent($name);
+    }
+
     /**
      * 󥪥֥Ȥ򥻥å
      * 
@@ -325,7 +360,9 @@ class SyL_DataManager
     function setAction()
     {
         if ($this->controller->container->isComponent(SYL_ACTION_KEY)) {
-            $this->action =& $this->controller->container->getComponent(SYL_ACTION_KEY);
+            $this->action =& $this->getComponent(SYL_ACTION_KEY);
+            // ץꥱ󥳥ݥͥȺ
+            $this->cm->deleteAppComponent();
         }
     }
 
@@ -339,8 +376,6 @@ class SyL_DataManager
     {
         return $this->action;
     }
-
-
 }
 
 ?>
