@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -47,15 +47,10 @@ class SyL_Error
     /**
      * 顼å
      * 
+     * @access public
      * @var array
      */
-    var $error_message = array();
-    /**
-     * ϥɥ᥽å̾
-     * 
-     * @var string
-     */
-    var $handler_method = 'errorHandler';
+    var $error_messages = array();
     /**
      * ԥ
      * 
@@ -63,6 +58,30 @@ class SyL_Error
      * @var string
      */
     var $eof = "\r\n";
+    /**
+     * ȥ饪֥
+     * 
+     * @access protected
+     * @var object
+     */
+    var $controller = null;
+    /**
+     * ǡ֥
+     * 
+     * @access protected
+     * @var object
+     */
+    var $dm = null;
+
+    /**
+     * 󥹥ȥ饯
+     *
+     * @access public
+     * @param object ȥ
+     */
+    function SyL_Error()
+    {
+    }
 
     /**
      * SyL_Error饹Υ󥹥󥹼
@@ -74,9 +93,9 @@ class SyL_Error
      *   $SyL_Error =& SyL_Error::getInstance();
      *
      * @access public
-     * @param string 顼
+     * @param object ȥ
      */
-    function &getInstance()
+    function &getInstance(&$controller)
     {
         static $singleton;
         if (!is_object($singleton)) {
@@ -84,12 +103,47 @@ class SyL_Error
             include_once SYL_INCLUDE_DIR . "/framework/Error/{$class_name}.php";
             // ҥ饹Υ󥹥
             $singleton = new $class_name();
-            // 顼ϥɥ饻å
-            call_user_func(array($singleton, 'setErrorHandler'));
+            $singleton->setController($controller);
         }
         return $singleton;
     }
 
+    /**
+     * ȥ򥻥å
+     *
+     * @access public
+     * @param object ȥ
+     */
+    function setController(&$controller)
+    {
+        $this->controller =& $controller;
+    }
+
+    /**
+     * 顼ϥɥ
+     * 
+     * @static
+     * @access public
+     */
+    function setErrorHandler()
+    {
+        $error =& SyL_Error::getInstance(null);
+        if ($error->controller->error_handler_method != '') {
+            set_error_handler(array(&$error->controller, $error->controller->error_handler_method));
+        }
+    }
+
+    /**
+     * 顼ϥɥ
+     * 
+     * @static
+     * @access public
+     */
+    function resetErrorHandler()
+    {
+        restore_error_handler();
+    }
+
     /**
      * 顼å򥻥å
      * 
@@ -99,8 +153,19 @@ class SyL_Error
      */
     function setErrorMessage($error_message)
     {
-        $e =& SyL_Error::getInstance();
-        $e->error_message[] = $error_message;
+        $error =& SyL_Error::getInstance(null);
+        $error->error_messages[] = $error_message;
+    }
+
+    /**
+     * 顼å
+     * 
+     * @access public
+     * @param string 顼å
+     */
+    function getErrorMessages()
+    {
+        return array_merge($this->error_messages, $this->controller->getErrorMessage());
     }
 
     /**
@@ -116,40 +181,13 @@ class SyL_Error
         trigger_error($error_string, $error_type);
     }
 
-    /**
-     * 顼ϥɥ
-     * 
-     * @static
-     * @access public
-     */
-    function setErrorHandler()
-    {
-        $e =& SyL_Error::getInstance();
-        set_error_handler(array(&$e, $e->handler_method));
-    }
-
-    /**
-     * 顼ϥɥ
-     * 
-     * @static
-     * @access public
-     */
-    function resetErrorHandler()
-    {
-        restore_error_handler();
-    }
-
     /**
      * 顼ϥɥ顼μ
      * 
-     * Loding Frameworkǥեȥ顼̤ܤȤ
-     * Ѥ롣
-     *
-     * @access abstruct
-     * @param  int 顼No
-     * @param  string 顼å
+     * @access public
+     * @param object ǡ֥
      */
-    function errorHandler( $error_no, $error_string ) {}
+    function errorHandler() {}
 
     /**
      * 顼פ֤
@@ -165,9 +203,9 @@ class SyL_Error
      * @param  int    顼No
      * @return string 顼̾
      */
-    function getErrorType($errorNo)
+    function getErrorType()
     {
-        switch ($errorNo) {
+        switch ($this->controller->getErrorNo()) {
         case E_ERROR           : return 'Error';
         case E_WARNING         : return 'Warning';
         case E_PARSE           : return 'Parsing Error';
@@ -180,8 +218,12 @@ class SyL_Error
         case E_USER_WARNING    : return 'User Warning';
         case E_USER_NOTICE     : return 'User Notice';
         default:
-          if (defined('E_STRICT') && ($errorNo == E_STRICT)) return 'Strict';
-          if (defined('E_RECOVERABLE_ERROR') && ($errorNo == E_RECOVERABLE_ERROR)) return 'Recoverable Error';
+            if (defined('E_STRICT') && ($errorNo == E_STRICT)) {
+                return 'Strict';
+            }
+            if (defined('E_RECOVERABLE_ERROR') && ($errorNo == E_RECOVERABLE_ERROR)) {
+                return 'Recoverable Error';
+            }
         }
 
         return 'Unknonwn';
@@ -197,15 +239,15 @@ class SyL_Error
     {
         // 顼ȥ졼
         $error_trace = array();
-        foreach (array_reverse(debug_backtrace()) as $value) {
+        foreach (array_reverse($this->controller->getErrorTrace()) as $value) {
             // 桼顼ϡtrigger_error״ؿʹߤӽ
             // ¾Υ顼ϡerrorhandler״ؿʹߤӽ
             if (isset($value['class']) && (strtolower($value['class']) == strtolower(get_class($this)))) {
                 break;
             }
             $tmp = array();
-            $tmp['file']     = isset($value['file'])     ? $value['file']     : '';
-            $tmp['line']     = isset($value['line'])     ? $value['line']     : '';
+            $tmp['file'] = isset($value['file']) ? $value['file'] : '';
+            $tmp['line'] = isset($value['line']) ? $value['line'] : '';
             if (isset($value['class']) && isset($value['type'])) {
                 $tmp['function'] = $value['class'] . $value['type'] . $value['function'];
             } else {
@@ -224,10 +266,11 @@ class SyL_Error
      * @param int 顼No
      * @param string 顼å
      */
-    function logging($error_no, $error_message)
+    function logging()
     {
+        $error_no = $this->controller->getErrorNo();
         if ($error_no <= SYL_DEBUG) {
-            $log_string  = '[' . $this->getErrorType($error_no) . '] ' . $error_message . $this->eof;
+            $log_string  = '[' . $this->getErrorType() . '] ' . implode($this->eof, $this->getErrorMessages()) . $this->eof;
             foreach ($this->getTrace() as $value) {
                 $log_string .= "[file] "     . $value['file'] . " ";
                 $log_string .= "[line] "     . $value['line'] . " ";
