@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,18 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.7 2006/12/23 11:12:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
 {
+    /**
+     * ɲåѥ᡼
+     * 
+     * @access protected
+     * @var string
+     */
+    var $parameter = array();
     /**
      * ɽƤΥǡ
      * 
@@ -58,53 +65,46 @@ class SyL_View
      * @var object
      */
     var $dm = null;
-    /**
-     * ݡͥȥ᥽åɥ֥
-     * 
-     * @access protected
-     * @var object
-     */
-    var $cm = null;
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
      */
-    function SyL_View(&$dm, &$cm)
+    function SyL_View(&$dm)
     {
         $this->dm =& $dm;
-        $this->cm =& $cm;
     }
 
     /**
      * ƥץ졼ȥ֥Ȥ
      * 
      * @access public
-     * @param object ӥ塼ǡ֥
+     * @param object ǡ֥
+     * @param object ݡͥȥ᥽åɥ֥
      * @return object ӥ塼֥
      */
-    function &getObject(&$dm, &$cm)
+    function &getObject(&$dm)
     {
-        $class_name   = '';
-        $include_file = '';
+        $class_name = '';
+        $class_file = '';
         $type = $dm->getTemplateType();
         if (strtolower($type) == 'customize') {
-            $class_name   = $dm->getCustomizedViewClass();
-            $include_file = $dm->getCustomizedViewFile();
-            if (!is_file($include_file)) {
-                $include_file1 = SYL_WEBAPP_LIB_DIR . "/{$include_file}";
-                if (!is_file($include_file1)) {
-                    trigger_error("[SyL error] Customised View file not found ({$include_file} or {$include_file1})", E_USER_ERROR);
+            $class_name = $dm->getCustomizedViewClass();
+            $class_file = $dm->getCustomizedViewFile();
+            if (!is_file($class_file)) {
+                $class_file1 = SYL_WEBAPP_LIB_DIR . "/{$class_file}";
+                if (!is_file($class_file1)) {
+                    trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
                 }
-                $include_file = $include_file1;
+                $class_file = $class_file1;
             }
         } else {
             $class_name = 'SyL_View' . ucfirst($type);
-            $include_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+            $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
         }
-        include_once $include_file;
-        $view =& new $class_name($dm, $cm);
+        include_once $class_file;
+        $view =& new $class_name($dm);
         return $view;
     }
 
@@ -130,6 +130,18 @@ class SyL_View
         return $this->dm->getTemplateFile();
     }
 
+    /**
+     * ɲåѥ᡼򥻥å
+     * 
+     * @access public
+     * @param string ѥ᡼̾
+     * @param string ѥ᡼
+     */
+    function setParameter($name, $value)
+    {
+        $this->parameter[$name] = $value;
+    }
+
     /**
      * ѥ᡼
      * 
@@ -170,6 +182,11 @@ class SyL_View
             }
         }
 
+        // ɲåѥ᡼
+        foreach ($this->parameter as $key => $value) {
+            $values[$key] = $value;
+        }
+
         return $values;
     }
 
