@@ -27,16 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ɽ饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
-
 /**
  * ǥեȥӥ塼饹
  *
@@ -44,7 +39,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewDefault.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewDefault.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewDefault extends SyL_View
@@ -54,9 +49,9 @@ class SyL_ViewDefault extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewDefault(&$dm, &$cm)
+    function SyL_ViewDefault(&$dm)
     {
-        parent::SyL_View($dm, $cm);
+        parent::SyL_View($dm);
     }
 
     /**
