@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,6 @@
  * Smarty饹
  */
 require_once SYL_SMARTY_DIR . 'Smarty.class.php';
-/**
- * ɽ饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
 
 /**
  * Smartyɽ饹
@@ -48,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.7 2006/12/23 11:12:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -65,9 +61,9 @@ class SyL_ViewSmarty extends SyL_View
      *
      * @access public
      */
-    function SyL_ViewSmarty(&$dm, &$cm)
+    function SyL_ViewSmarty(&$dm)
     {
-        parent::SyL_View($dm, $cm);
+        parent::SyL_View($dm);
 
         $this->smarty =& new Smarty();
         $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
